package WebService::dSS::Role::Nameable;

# ABSTRACT: Role for objects that have a name

use Moose::Role;
use MooseX::FollowPBP;
use Moose::Util::TypeConstraints;
use Carp;
use namespace::autoclean;


=head1 SYNOPSIS

	with 'WebService::dSS::Role::Nameable';

=head1 DESCRIPTION

WebService::dSS::Role::Nameable is a role for objects that have a name which
may also be changed.

=head1 METHODS

=head2 set_name

Setter for the objects's name.

=head3 Parameters

This method expects positional parameters.

=over

=item new_name

The new name for the object.

=back

=cut

sub set_name {
	my ($self, $new_name) = @_;

	unless (defined $new_name && $new_name ne '') {
		croak("Required 'new_name' parameter not passed");
	}

	my $base_params = $self->get_name_base_params();
	unless (defined $base_params && ref $base_params eq 'HASH'
			&& ref $base_params->{write} eq 'HASH') {
		croak('get_name_base_params() returned invalid base parameter value');
	}

	my $call_arg = {%{$base_params->{write}}};
	$call_arg->{param} = {
		%{$call_arg->{param}},
		newName => $new_name
	};

	$self->get_api()->call($call_arg);

	$self->_set_name($new_name);

	return;
}

=head1 ROLES

WebService::dSS::Role::Nameable does the following roles:

=over

=item *

L<WebService::dSS::Role::Named|WebService::dSS::Role::Named>

=back

=cut

with 'WebService::dSS::Role::Named';

1;

