package WebService::dSS::Role::Named;

# ABSTRACT: Role for objects that have a name

use Moose::Role;
use MooseX::FollowPBP;
use Moose::Util::TypeConstraints;
use namespace::autoclean;

use Carp;

requires qw(get_name_base_params get_api);


=head1 SYNOPSIS

	with 'WebService::dSS::Role::Named';

=head1 DESCRIPTION

WebService::dSS::Role::Named is a role for objects that have a name.

=head1 METHODS

=cut

=head2 get_name

Getter for the object's name.

=head3 Result

The name of the object.

=cut

has 'name' => (
	is       => 'ro',
	isa      => 'Str',
	required => 0,
	lazy     => 1,
	reader   => 'get_name',
	writer   => '_set_name',
	default  => sub {
		my ($self) = @_;

		my $base_params = $self->get_name_base_params();
		unless (defined $base_params && ref $base_params eq 'HASH'
				&& ref $base_params->{read} eq 'HASH') {
			croak('get_name_base_params() returned invalid base parameter value');
		}

		my $result = $self->get_api()->call($base_params->{read});
		my $callback = $base_params->{read}->{callback};
		if (defined $callback) {
			return $callback->($result);
		}
		else {
			return $result->{name};
		}
	}
);

1;
