package WebService::dSS::Role::Switchable;

# ABSTRACT: Role for objects that can be turned on and off

use Moose::Role;
use MooseX::FollowPBP;
use Moose::Util::TypeConstraints;
use namespace::autoclean;

requires qw(get_switch_base_params get_api);

use Carp;

=head1 SYNOPSIS

	with 'WebService::dSS::Role::Switchable';

=head1 DESCRIPTION

WebService::dSS::Role::Switchable is a role for objects which can be turned on
and off.

=head1 METHODS

=head2 turn_on

Turn the object on.

=head3 Result

Nothing on success, an exception otherwise.

=cut

sub turn_on {
	my ($self, $new_name) = @_;

	return $self->_turn('On');
}


=head2 turn_off

Turn the object off.

=head3 Result

Nothing on success, an exception otherwise.

=cut

sub turn_off {
	my ($self, $new_name) = @_;

	return $self->_turn('Off');
}


# Do the actual work

sub _turn {
	my ($self, $state) = @_;

	unless (defined $state && $state ne '') {
		croak("Required 'state' parameter not passed");
	}

	my $base_params = $self->get_switch_base_params();
	unless (defined $base_params && ref $base_params eq 'HASH'
			&& ref $base_params->{lc($state)} eq 'HASH') {
		croak('get_switchable_base_params() returned invalid base parameter value');
	}

	$self->get_api()->call( $base_params->{lc($state)} );

	return;
}

1;

