package WebService::dSS::Apartment::Zone::GroupTest;
use base qw(WebService::dSS::TestBase);

use strict;
use warnings;

use Carp;
use Test::More;
use Test::Exception;

use WebService::dSS;
use WebService::dSS::Apartment::Zone;
use WebService::dSS::Apartment::Zone::Group;


sub new_test : Test(3) {
	my ($self) = @_;

	my $apartment = WebService::dSS->new({
		url => $self->get_base_url(0),
	})->get_apartment();

	my $zone = WebService::dSS::Apartment::Zone->new({
		apartment => $apartment,
		id        => 1,
	});

	my $group = WebService::dSS::Apartment::Zone::Group->new({
		zone => $zone,
		id   => 1
	});

	isa_ok($group, 'WebService::dSS::Apartment::Zone::Group', 'group created');
	is($group->get_zone(), $zone, 'zone stored');
	is($group->get_id(), 1, 'id stored');
}


sub turn_on_off_test : Test(2) {
	my ($self) = @_;

	my $group = $self->create_group_instance();

	lives_ok(sub { $group->turn_on() },  'turned on');
	lives_ok(sub { $group->turn_off() }, 'turned off');
}


sub get_name_test : Test(2) {
	my ($self) = @_;

	my $group = $self->create_group_instance();

	is($group->get_name(), 'yellow', 'got name');

	$group = WebService::dSS::Apartment::Zone::Group->new({
		zone => $self->create_zone_instance(),
		id   => 1,
		name => 'foo',
	});
	is($group->get_name(), 'foo', 'got name');
}


sub create_zone_instance {
	my ($self) = @_;

	my $apartment = WebService::dSS->new({
		url => $self->get_base_url(0),
		ua  => $self->get_fake_ua(),
	})->get_apartment();

	return WebService::dSS::Apartment::Zone->new({
		apartment => $apartment,
		id        => 1,
	});
}

sub create_group_instance {
	my ($self) = @_;

	return WebService::dSS::Apartment::Zone::Group->new({
		zone => $self->create_zone_instance(),
		id   => 1,
	});
}


1;
