package WebService::dSS::Apartment::ZoneTest;
use base qw(WebService::dSS::TestBase);

use strict;
use warnings;

use Carp;
use Test::More;
use Test::Exception;

use WebService::dSS;
use WebService::dSS::Apartment;
use WebService::dSS::Apartment::Zone;

sub new_test : Test(1) {
	my ($self) = @_;

	my $apartment = WebService::dSS->new({
		url => $self->get_base_url(0),
	})->get_apartment();

	my $zone = WebService::dSS::Apartment::Zone->new({
		apartment => $apartment,
		id        => 0,
	});

	isa_ok($zone, 'WebService::dSS::Apartment::Zone', 'zone created');
}


sub get_set_name_test : Test(2) {
	my ($self) = @_;

	my $zone = $self->create_zone_instance();

	is($zone->get_name(), 'foo', 'got name');
	lives_ok(sub { $zone->set_name('bar') } , 'name set');
}


sub turn_on_off_test : Test(2) {
	my ($self) = @_;

	my $zone = $self->create_zone_instance();

	lives_ok(sub { $zone->turn_on() },  'turned on');
	lives_ok(sub { $zone->turn_off() }, 'turned off');
}


sub get_groups_test : Test(28) {
	my ($self) = @_;

	my $zone = $self->create_zone_instance();

	# Basic call
	my @groups = $zone->get_groups();
	is(scalar @groups, 1, 'correct group count');
	foreach my $group (@groups) {
		isa_ok($group, 'WebService::dSS::Apartment::Zone::Group', 'group returned')
	}

	# Check inclusion of empty groups
	@groups = $zone->get_groups({
		include_empty => 1,
	});
	is(scalar @groups, 10, 'correct group count');
	foreach my $group (@groups) {
		isa_ok($group, 'WebService::dSS::Apartment::Zone::Group', 'group returned')
	}

	# Check inclusion of broadcast group
	@groups = $zone->get_groups({
		include_broadcast => 1,
	});
	is(scalar @groups, 2, 'correct group count');
	foreach my $group (@groups) {
		isa_ok($group, 'WebService::dSS::Apartment::Zone::Group', 'group returned')
	}

	# Check inclusion of broadcast group and empty groups
	@groups = $zone->get_groups({
		include_broadcast => 1,
		include_empty     => 1,
	});
	is(scalar @groups, 11, 'correct group count');
	foreach my $group (@groups) {
		isa_ok($group, 'WebService::dSS::Apartment::Zone::Group', 'group returned')
	}
}


sub create_zone_instance {
	my ($self) = @_;

	my $apartment = WebService::dSS->new({
		url => $self->get_base_url(0),
	})->get_apartment();

	my $zone = WebService::dSS::Apartment::Zone->new({
		apartment => $apartment,
		id        => 1,
	});

	return $zone;
}

1;
