package WebService::dSS::ApartmentTest;
use base qw(WebService::dSS::TestBase);

use strict;
use warnings;

use Carp;
use Test::More;
use Test::Exception;

use WebService::dSS;
use WebService::dSS::Apartment;


sub new_test : Test(1) {
	my ($self) = @_;

	my $api = WebService::dSS->new({
		url => $self->get_base_url(0),
	});

	my $apartment = WebService::dSS::Apartment->new({
		api => $api,
	});

	isa_ok($apartment, 'WebService::dSS::Apartment', 'apartment created');
}


sub get_set_name_test : Test(2) {
	my ($self) = @_;

	my $apartment = WebService::dSS->new({
		url => $self->get_base_url(0),
	})->get_apartment();

	is($apartment->get_name(), 'dSS', 'got name');
	lives_ok(sub { $apartment->set_name('new name') } , 'name set');
}


sub get_zones_test : Test(6) {
	my ($self) = @_;

	my $apartment = WebService::dSS->new({
		url => $self->get_base_url(0),
	})->get_apartment();

	# Only 'normal' zones
	my @zones = $apartment->get_zones();
	is(scalar(@zones), 1, 'zones returned');
	foreach my $zone (@zones) {
		isa_ok($zone, 'WebService::dSS::Apartment::Zone', 'zone returned');
		isnt($zone->get_id(), 0, 'zone 0 filtered');
	}

	# Include 'all' zone
	@zones = $apartment->get_zones({
		include_all => 1
	});
	is(scalar(@zones), 2, 'zones returned');
	foreach my $zone (@zones) {
		isa_ok($zone, 'WebService::dSS::Apartment::Zone', 'zone returned');
	}
}


sub turn_on_off_test : Test(2) {
	my ($self) = @_;

	my $apartment = WebService::dSS->new({
		url => $self->get_base_url(0),
	})->get_apartment();

	lives_ok(sub { $apartment->turn_on() },  'turned on');
	lives_ok(sub { $apartment->turn_off() }, 'turned off');
}


1;
