package WebService::dSS::TestBase;
use base qw(Test::Class);

use strict;
use warnings;

use Carp;
use Test::More;
use Test::Exception;
use Readonly;
use URI::file;
use Path::Class::Dir;
use Test::MockObject::Extends;
use LWP::UserAgent;
use HTTP::Response;
use File::Slurp;

Readonly my $base_dir => Path::Class::Dir->new('t', 'testdata')->absolute();

sub get_base_dir {
	my ($self) = @_;
	return $base_dir;
}

sub get_base_url {
	my ($self, $suffix) = @_;
	return URI::file->new($self->get_base_dir()->subdir($suffix));
}

sub get_fake_ua {
	my ($self) = @_;

	my $ua      = LWP::UserAgent->new();
	my $ua_mock = Test::MockObject::Extends->new($ua);

	$ua_mock->mock('get', sub {
		my ($self, $url) = @_;

		return HTTP::Response->new(200, 'Ok', [], read_file($url->path));
	});

	return $ua_mock;
}

1;
